@@ -218,16 +218,19 @@ def get_metric_units(dataset, raise_error=False):
     # function to get m.u. with possibility to raise error
     _metric_units = {  # from /qa4sm/validator/validation/graphics.py
         'ISMN': 'm³/m³',
-        'C3S': 'm³/m³',
+        'C3S': 'm³/m³',  # old name
+        'C3S_combined': 'm³/m³',
         'GLDAS': 'm³/m³',
         'ASCAT': '% saturation',
-        'SMAP': 'm³/m³',
+        'SMAP': 'm³/m³',   # old name
+        'SMAP_L3': 'm³/m³',
         'ERA5': 'm³/m³',
         'ERA5_LAND': 'm³/m³',
         'ESA_CCI_SM_active': '% saturation',
         'ESA_CCI_SM_combined': 'm³/m³',
         'ESA_CCI_SM_passive': 'm³/m³',
-        'SMOS': 'm³/m³',
+        'SMOS': 'm³/m³',   # old name
+        'SMOS_IC': 'm³/m³',
         'CGLS_CSAR_SSM1km': '% saturation',
         'CGLS_SCATSAR_SWI1km': '% saturation',
         'SMOS_L3': 'm³/m³',
@@ -282,16 +285,19 @@ _metric_name = {  # from /qa4sm/validator/validation/globals.py
 # fallback for dataset pretty names in case they are not in the metadata
 _dataset_pretty_names = {  # from qa4sm\validator\fixtures\datasets.json
     'ISMN': 'ISMN',
-    'C3S': 'C3S',
+    'C3S_combined': 'C3S SM combined',
+    'C3S': 'C3S SM combined',  # old name for C3S_combined
     'GLDAS': 'GLDAS',
     'ASCAT': 'H-SAF ASCAT SSM CDR',
-    'SMAP': 'SMAP level 3',
+    'SMAP_L3': 'SMAP level 3',
+    'SMAP': 'SMAP level 3',  # old name for SMAP_L3
     'ERA5': 'ERA5',
     'ERA5_LAND': 'ERA5-Land',
     'ESA_CCI_SM_active': 'ESA CCI SM active',
     'ESA_CCI_SM_combined': 'ESA CCI SM combined',
     'ESA_CCI_SM_passive': 'ESA CCI SM passive',
-    'SMOS': 'SMOS IC',
+    'SMOS_IC': 'SMOS IC',
+    'SMOS': 'SMOS IC',  # old name for SMOS IC
     'CGLS_CSAR_SSM1km': 'CGLS S1 SSM',
     'CGLS_SCATSAR_SWI1km': 'CGLS SCATSAR SWI',
     'SMOS_L3': 'SMOS L3',
@@ -383,16 +389,19 @@ def get_resolution_info(dataset, raise_error=False):
 
     resolution = {  # from /qa4sm/validator/fixtures/datasets.json
         'ISMN': None,
-        'C3S': 0.25,
+        'C3S_combined': 0.25,
+        'C3S': 0.25,   # old name, unused
         'GLDAS': 0.25,
         'ASCAT': 12.5,
-        'SMAP': 36,
+        'SMAP': 36,   # old name, unused
+        'SMAP_L3': 36,
         'ERA5': 0.25,
         'ERA5_LAND': 0.1,
         'ESA_CCI_SM_active': 0.25,
         'ESA_CCI_SM_combined': 0.25,
         'ESA_CCI_SM_passive': 0.25,
-        'SMOS': 25,
+        'SMOS': 25,   # old name, unused
+        'SMOS_IC': 25,
         'CGLS_CSAR_SSM1km': 1,
         'CGLS_SCATSAR_SWI1km': 1,
         'SMOS_L3': 25,
@@ -401,16 +410,19 @@ def get_resolution_info(dataset, raise_error=False):
     # fallback for resolution unit information
     resolution_units = {  # from /qa4sm/validator/fixtures/datasets.json
         'ISMN': 'point',
-        'C3S': 'deg',
+        'C3S': 'deg',  # old name, unused
+        'C3S_combined': 'deg',
         'GLDAS': 'deg',
         'ASCAT': 'km',
-        'SMAP': 'km',
+        'SMAP': 'km',   # old name, unused
+        'SMAP_L3': 'km',
         'ERA5': 'deg',
         'ERA5_LAND': 'deg',
         'ESA_CCI_SM_active': 'deg',
         'ESA_CCI_SM_combined': 'deg',
         'ESA_CCI_SM_passive': 'deg',
-        'SMOS': 'km',
+        'SMOS': 'km',   # old name, unused
+        'SMOS_IC': 'km',
         'CGLS_CSAR_SSM1km': 'km',
         'CGLS_SCATSAR_SWI1km': 'km',
         'SMOS_L3': 'deg',
