@@ -1,5 +1,7 @@
 # test for functions that plot all the images. Use pytest.long_run to avoid running it for development
 import os
+import sys
+
 import pytest
 import tempfile
 import shutil
@@ -7,6 +9,12 @@ import shutil
 import qa4sm_reader.plot_all as pa
 
 
+# if sys.platform.startswith("win"):
+#     pytestmark = pytest.mark.skip(
+#         "Failing on Windows."
+#     )
+
+
 @pytest.fixture
 def plotdir():
     plotdir = tempfile.mkdtemp()
@@ -28,8 +36,8 @@ def test_plot_all(plotdir):
         save_metadata=True,
     )
 
-    assert len(os.listdir(plotdir)) == 59
-    assert all(os.path.splitext(file)[1] == ".png" for file in os.listdir(plotdir)), \
-        "Not all files have been saved as .png"
+    assert len(os.listdir(plotdir)) == 60
+    assert all(os.path.splitext(file)[1] in [".png", ".csv"] for file in os.listdir(plotdir)), \
+        "Not all files have been saved as .png or .csv"
 
     shutil.rmtree(plotdir)
